==> haskell-crypto-api-0.13.2-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-crypto-api/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api
version: 0.13.2
id: crypto-api-0.13.2-4fad3356ee1ec2ae527f720a8a7be373
key: crypt_5qMYdrITLWmJ49NnxgNYC6
license: BSD3
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/crypto-api
synopsis: A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.
category: Data, Cryptography
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)
exposed: True
exposed-modules:
    Crypto.Classes Crypto.Types Crypto.HMAC Crypto.Random
    Crypto.Padding Crypto.Modes Crypto.Util Crypto.Classes.Exceptions
hidden-modules: Crypto.CPoly
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-api-0.13.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-api-0.13.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/crypto-api-0.13.2
hs-libraries: HScrypto-api-0.13.2-5qMYdrITLWmJ49NnxgNYC6
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    entropy-0.3.7-db9feabff8921cc1dd6e8db21278a74f
    tagged-0.8.2-849e3b2865ae1877e32ec9d4d01c3d0a
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html: /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-api-0.13.2-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-crypto-api/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-api
version: 0.13.2
id: crypto-api-0.13.2-095d0cf567bb83558b8b8ae881dd04fd
key: crypt_Kp4uvZbywBzKttuHrlYBAx
license: BSD3
copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
homepage: https://github.com/TomMD/crypto-api
synopsis: A generic interface for cryptographic operations
description:
    A generic interface for cryptographic operations (hashes, ciphers, randomness).
    Maintainers of hash and cipher implementations are
    encouraged to add instances for the classes defined
    in Crypto.Classes.  Crypto users are similarly
    encouraged to use the interfaces defined in the Classes
    module.
    Any concepts or functions of general use to more than
    one cryptographic algorithm (ex: padding) is within
    scope of this package.
category: Data, Cryptography
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>, Francisco Blas Izquierdo Riera (klondike)
exposed: True
exposed-modules:
    Crypto.Classes Crypto.Types Crypto.HMAC Crypto.Random
    Crypto.Padding Crypto.Modes Crypto.Util Crypto.Classes.Exceptions
hidden-modules: Crypto.CPoly
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-api-0.13.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-api-0.13.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/crypto-api-0.13.2
hs-libraries: HScrypto-api-0.13.2-Kp4uvZbywBzKttuHrlYBAx
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    entropy-0.3.7-db9feabff8921cc1dd6e8db21278a74f
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
haddock-html: /usr/share/doc/haskell-crypto-api/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
